Learn R Programming

AntMAN (version 1.1.0)

IAM_VnkDelta: Compute the value V(n,k), needed to caclulate the eppf of a Finite Dirichlet process when the prior on the component-weigts of the mixture is a Dirichlet with parameter gamma (i.e. when unnormailized weights are distributed as Gamma(\(\gamma\),1) ) when the number of component are fixed to M^*, i.e. a Dirac prior assigning mass only to M^* is assumed. See Section 9.1.1 of the Paper Argiento de Iorio 2019 for more details.

Description

There are no default values.

Usage

IAM_VnkDelta(n, Mstar, gamma)

Arguments

n

The sample size

Mstar

The number of component of the mixture

gamma

The gamma parameter of the Dirichlet

Value

A vector of length n, reporting the values V(n,k) for k=1,...,n