gamma (i.e. when unnormailized weights are distributed as Gamma(\(\gamma\),1) ) when the prior on the number of componet is Negative Binomial with parameter r and pwith mean is mu =1+ r*p/(1-p) TODO: CHECK THIS FORMULA!!!. See Section 9.1.1 of the Paper Argiento de Iorio 2019 for more detailsThere are no default values.
IAM_VnkNegBin(n, r, p, gam)The sample size
The dispersion parameter r of Negative Binomial
The probability of failure parameter p of Negative Binomial
The gamma parameter of the Dirichlet
A vector of length n, reporting the values V(n,k) for k=1,...,n