gamma (i.e. when unnormailized weights are distributed as Gamma(\(\gamma\),1) )
when the number of component are fixed to M^*, i.e. a Dirac prior assigning mass only to M^* is assumed.
See Section 9.1.1 of the Paper Argiento de Iorio 2019 for more details.There are no default values.
IAM_VnkDelta(n, Mstar, gamma)The sample size
The number of component of the mixture
The gamma parameter of the Dirichlet
A vector of length n, reporting the values V(n,k) for k=1,...,n